@@ -5,7 +5,7 @@ pub fn main() {
     // If the "logging" feature is enabled, Wolf Engine includes a default logger for
     // convenience, but using it is optional.  Feel free to bring your own logger instead.
     #[cfg(feature = "logging")]
-    initialize_logging(LevelFilter::Debug);
+    logging::initialize_logging(LevelFilter::Debug);
 
     // Initialize your game state.
     let game = FizzBuzzState::new();
