@@ -5,8 +5,9 @@
 //!
 //! # Getting Started
 //!
-//! If you don't care about customizing the engine's behavior, [Engine::new()] is the
-//! fastest way to get up and running.
+//! Wolf Engine ships with sensible defaults to help jump-start projects as quickly as
+//! possible.  You can get started with the default settings by calling [Engine::new()],
+//! or alternatively [Engine::default()].
 //!
 //! ```
 //! # use wolf_engine::{Engine, EmptyState};
@@ -17,6 +18,12 @@
 //!     .run(Box::from(my_game_state));
 //! ```
 //!
+//! The defaults are probably fine for simple projects, or when you're just getting
+//! started.  You can reference the [Engine]'s documentation if you want to customize the
+//! engine.
+//!
+//! ## Game States
+//!
 //! Wolf Engine games are organized into one or more game [State]s.  These game [State]s
 //! bundle your game's data and logic into a single package that's easy to pass to the
 //! [Engine].  You will need to implement your game as a [State].
@@ -42,19 +49,12 @@
 //! for more complete examples of how to use Wolf Engine.  The [Quick-start Example](https://github.com/AlexiWolf/wolf_engine/blob/main/examples/quickstart.rs)
 //! is a good starting place.
 
-mod engine;
-mod state;
+mod core;
+
+pub mod contexts;
+pub mod schedulers;
 
 #[cfg(feature = "logging")]
-mod logging;
+pub mod logging;
 
-pub mod context;
-pub mod core;
-pub mod scheduler;
-
-pub use context::Context;
-pub use engine::*;
-pub use state::*;
-
-#[cfg(feature = "logging")]
-pub use logging::*;
+pub use crate::core::*;
